package com.ruoyi.system.mapper;

import java.util.List;
import com.ruoyi.system.domain.ManageDeviceDictionary;
import org.apache.ibatis.annotations.Param;

/**
 * Device product enumMapper接口
 *
 * @author ruoyi
 * @date 2024-09-03
 */
public interface ManageDeviceDictionaryMapper
{
    /**
     * 查询Device product enum
     *
     * @param id Device product enum主键
     * @return Device product enum
     */
    public ManageDeviceDictionary selectManageDeviceDictionaryById(Integer id);

    /**
     * 查询Device product enum列表
     *
     * @param manageDeviceDictionary Device product enum
     * @return Device product enum集合
     */
    public List<ManageDeviceDictionary> selectManageDeviceDictionaryList(ManageDeviceDictionary manageDeviceDictionary);

    /**
     * 新增Device product enum
     *
     * @param manageDeviceDictionary Device product enum
     * @return 结果
     */
    public int insertManageDeviceDictionary(ManageDeviceDictionary manageDeviceDictionary);

    /**
     * 修改Device product enum
     *
     * @param manageDeviceDictionary Device product enum
     * @return 结果
     */
    public int updateManageDeviceDictionary(ManageDeviceDictionary manageDeviceDictionary);

    /**
     * 删除Device product enum
     *
     * @param id Device product enum主键
     * @return 结果
     */
    public int deleteManageDeviceDictionaryById(Integer id);

    /**
     * 批量删除Device product enum
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteManageDeviceDictionaryByIds(Integer[] ids);

    ManageDeviceDictionary selectManageDeviceDictionaryByCondition(@Param("domain") String s, @Param("deviceType")String s1, @Param("subType")String s2);
}
